use strict;
use warnings;

package CORBA::Perl;

our $VERSION = '0.40';

1;

